# max_ard

A Python SDK and CLI for working with ARD Imagery

## Introduction

`max_ard` consists of a Python SDK for selecting, ordering, and working with Maxar ARD imagery and a set of CLI tools  for common tasks.

## Installation

For now, download release files from the release section in Github then install it with `pip`:

`pip install max-ard.<other stuff>`

This will be the official way to install:

`pip install max-ard --extra-index-url https://ard.maxar.com/packages`

## Prerequisites

If you are using the SDK or CLI to access data in an S3 bucket, you will need to configure your AWS credentials locally. If you install the AWS CLI tools and and can `aws s3 ls <bucket>` then you're set to go.

To interact with the ARD services, you also need to have ARD account credentials. Currently we store the credentials locally in a file in your home directory called `.ard-config`. It should contain:

```shell
[ard]
user_name = <your user name>
user_password = <your password>
```

The CLI tools can be used to create this file:

`max-ard login --username <your username> --password <your password`

Tools for browsing ARD data currently have an optimization that uses GBDX systems. If you do not have GBDX credentials the optimization is skipped. This dependency will be moved to use the ARD system in the future.

## Documentation

The most current general ARD documentation is here for now:

http://ard-docs.s3-website-us-east-1.amazonaws.com/dev/

General ARD documentation will be at https://ard.maxar.com/docs.

The documents for the SDK  are in the `/docs` directory, but will be published to  https://ard.maxar.com/sdk-docs soon.

## Development

This project uses Poetry for managing development. To get started using Poetry, ensure it is installed as per: https://python-poetry.org/docs/#installation.

To get started with development, create a local virtual env and install all the dependencies:

```shell
poetry config virtualenvs.in-project true --local
poetry install --extras full
```

If during development a new dependency is required, it can be added with the following:

```shell
poetry add <pkg_name> [--dev]
```

### Run Tests

There are some required env vars for running the tests, they can be found in the [.env-sample](.env-sample) file. It is up to the user to have those env vars active before running the tests. This file can be copied to a `.env` file (ARD creds need to be added), to be used with tools that support the format.

To run the tests prior to creating a PR:

```shell
poetry run ./scripts/tests
```

## Releases

The script for making a new release is [scripts/release](scripts/release). This can me called directly as follows:

```shell
./scripts/release patch|minor|major|prepatch|preminor|premajor|...
```

The semver argument will be passed to Poetry, see the Poetry docs for the different arguments: https://python-poetry.org/docs/cli/#version

For pre-releases, having a current version of 0.0.1, a pre-release version can be bumped by using `poetry version prepatch`, which will result in `0.0.2-alpha.0`. Then to bump to `0.0.2`, run `poetry version patch`.

## Update Documentation

To trigger a build of the docs and to publish to S3, run the following script:

```shell
./scripts/update_docs
```

This script will create a branch called `update_docs`, reset it to the current `master` branch, and push. Which will trigger the CircleCI workflow to build and publish the latest documentation.
